﻿// --------------------------------------------------------------------------------------------------------------------
// <copyright file="ContourSeriesExamples.cs" company="OxyPlot">
//   The MIT License (MIT)
//
//   Copyright (c) 2012 Oystein Bjorke
//
//   Permission is hereby granted, free of charge, to any person obtaining a
//   copy of this software and associated documentation files (the
//   "Software"), to deal in the Software without restriction, including
//   without limitation the rights to use, copy, modify, merge, publish,
//   distribute, sublicense, and/or sell copies of the Software, and to
//   permit persons to whom the Software is furnished to do so, subject to
//   the following conditions:
//
//   The above copyright notice and this permission notice shall be included
//   in all copies or substantial portions of the Software.
//
//   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
//   OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
//   MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
//   IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
//   CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
//   TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
//   SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
// </copyright>
// --------------------------------------------------------------------------------------------------------------------
using OxyPlot;

namespace ExampleLibrary
{
    using System;

    using OxyPlot.Axes;
    using OxyPlot.Series;

    [Examples("ContourSeries")]
    public class ContourSeriesExamples : ExamplesBase
    {
        private static Func<double, double, double> peaks = (x, y) =>
               3 * (1 - x) * (1 - x) * Math.Exp(-(x * x) - (y + 1) * (y + 1))
               - 10 * (x / 5 - x * x * x - y * y * y * y * y) * Math.Exp(-x * x - y * y)
               - 1.0 / 3 * Math.Exp(-(x + 1) * (x + 1) - y * y);

        [Example("Peaks")]
        public static PlotModel Peaks()
        {
            var model = new PlotModel("Peaks");
            var cs = new ContourSeries
                {
                    ColumnCoordinates = ArrayHelper.CreateVector(-3, 3, 0.05),
                    RowCoordinates = ArrayHelper.CreateVector(-3.1, 3.1, 0.05)
                };
            cs.Data = ArrayHelper.Evaluate(peaks, cs.ColumnCoordinates, cs.RowCoordinates);
            model.Subtitle = cs.Data.GetLength(0) + "×" + cs.Data.GetLength(1);
            model.Series.Add(cs);
            return model;
        }

        [Example("Peaks (different contour colors)")]
        public static PlotModel PeaksWithColors()
        {
            var model = new PlotModel("Peaks");
            var cs = new ContourSeries
            {
                ColumnCoordinates = ArrayHelper.CreateVector(-3, 3, 0.05),
                RowCoordinates = ArrayHelper.CreateVector(-3.1, 3.1, 0.05),
                ContourColors = new[] { OxyColors.SeaGreen, OxyColors.RoyalBlue, OxyColors.IndianRed }
            };
            cs.Data = ArrayHelper.Evaluate(peaks, cs.ColumnCoordinates, cs.RowCoordinates);
            model.Subtitle = cs.Data.GetLength(0) + "×" + cs.Data.GetLength(1);
            model.Series.Add(cs);
            return model;
        }

        [Example("Peaks (wide array)")]
        public static PlotModel WideArrayPeaks()
        {
            var model = new PlotModel("Peaks");
            model.Axes.Add(new LinearAxis(AxisPosition.Left, -3.16262, 3.162));
            var cs = new ContourSeries
            {
                ColumnCoordinates = ArrayHelper.CreateVector(-3, 3, 0.05),
                RowCoordinates = ArrayHelper.CreateVector(-1, 1, 0.05)
            };
            cs.Data = ArrayHelper.Evaluate(peaks, cs.ColumnCoordinates, cs.RowCoordinates);
            model.Subtitle = cs.Data.GetLength(0) + "×" + cs.Data.GetLength(1);
            model.Series.Add(cs);
            return model;
        }

    }
}